----------------------------------------------------------------------------------
-- ********* FleaFPGA Platform top-level wrapper for PCB Revision 2.4 ***********
--
-- ********* Example #3 - Pong clone example using VGA and PS/2 keyboard ********
--
-- Keys 'A' and 'Z' control paddle #1, while Keys 'K' and 'M' control paddle #2 - enjoy!
--
-- Please Note: I am not the owner of the HDL code contained in pong.vhd and
-- KeyboardController.vhd - please see the LICENSE file for details. This source 
-- code is provided as-is and is only intended to illustrate how to implement a simple 
-- VHDL project using FleaFPGA.
--
-- Creation Date: 15th December 2013
-- Author: Valentin Angelovski
--
-- 2013 - Valentin Angelovski
----------------------------------------------------------------------------------


library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.numeric_std.ALL;

entity FleaFPGA_2v4 is

  port(
    -- System clock and reset
	sys_clock		: in    std_logic;  -- main clock input from external clock source
	sys_reset		: in    std_logic;  -- main clock input from external RC reset circuit

    -- On-board user buttons and status LEDs
	n_pb1			: in    std_logic;  
	n_pb2			: in    std_logic;  
	n_led1			: buffer  std_logic;
	n_led2			: buffer  std_logic;
	n_led3			: buffer  std_logic;
	n_led4			: buffer  std_logic;

    -- USB Host (CH376T) interface
	host_reset		: out  std_logic;
	host_spi		: out  std_logic;
	host_nInt		: in  std_logic;
	host_sdi 		: buffer  std_logic;
	host_sdo		: in  std_logic;
	host_sck		: buffer  std_logic;	
	host_cs			: buffer  std_logic;
	host_tx_o 		: out  std_logic;
	host_rx_i 		: in  std_logic;
	
    -- USB Slave (FT230x) interface 
	slave_tx_o 		: out  std_logic;
	slave_rx_i 		: in  std_logic;
	
    -- User GPIO (18 I/O pins) Header
	GPIO 			: inout std_logic_vector(18 downto 1);  -- GPIO Header pins available as one data block
	
	-- SDRAM interface (For use with 16Mx16bit or 32Mx16bit SDR DRAM, depending on version)
	Dram_Clk		: out   std_logic;     -- clock to SDRAM
	Dram_n_Ras		: out   std_logic;     -- SDRAM RAS
	Dram_n_Cas		: out   std_logic;     -- SDRAM CAS
	Dram_n_We		: out   std_logic;     -- SDRAM write-enable
	Dram_BA			: out   std_logic_vector(1 downto 0);   -- SDRAM bank-address
	Dram_Addr		: out   std_logic_vector(12 downto 0);  -- SDRAM address bus
	Dram_Data		: inout std_logic_vector(15 downto 0);  -- data bus to/from SDRAM
	Dram_n_cs		: out   std_logic; 
	Dram_dqm		: out   std_logic_vector(1 downto 0); 
	Dram_DQMH		: out   std_logic;
	Dram_DQML		: out   std_logic;	
	
	-- VGA interface (Note: 12-bit color organized as RGB = 4/4/4-bits)
	vga_vs			: out   std_logic; 
	vga_hs			: out   std_logic; 
	vga_red			: out   std_logic_vector(3 downto 0); 
	vga_green		: out   std_logic_vector(3 downto 0); 
	vga_blue		: out   std_logic_vector(3 downto 0); 
	
	-- SD/MMC Interface (Support either SPI or nibble-mode)
	mmc_dat1		: in   std_logic; 
	mmc_dat2		: in   std_logic; 
	mmc_n_cs		: out   std_logic; 
	mmc_clk			: out   std_logic; 
	mmc_mosi		: out   std_logic; 
	mmc_miso		: in   std_logic; 

	-- Audio out (stereo-PWM) interface	
	Audio_l			: buffer   std_logic; 
	Audio_r			: buffer   std_logic; 
	
	-- PS2 interface (Both ports accessible via Y-splitter cable)
	PS2_clk1		: inout    std_logic;
	PS2_data1		: inout    std_logic;
	PS2_clk2		: inout     std_logic;
	PS2_data2		: inout     std_logic

    );
end FleaFPGA_2v4;


   
architecture arch of FleaFPGA_2v4 is


   
begin
  -- Housekeeping logic for unwanted peripherals on FleaFPGA board goes here!!!
  -- (Note: comment out any of the following code lines if peripheral is required)
  host_cs <= '1'; 	-- USB host SPI interface disabled
  Dram_n_cs <= '1'; -- DRAM disabled 
  mmc_n_cs <= '1';  -- SD/MMC card disabled
  

	
  -- User HDL project port mappings go here!

  -- Note: user_module1 illustrates how to integrate a more complex module (pong video game)

	user_module1 : entity work.pong
    Port map(
		clk => sys_clock,
		hsync_out => vga_hs,
		vsync_out => vga_vs,
		red_out => vga_red(3),
		green_out => vga_green(3),
		blue_out => vga_blue(3),
		soundPin => Audio_l,	
		kb_clk  => PS2_clk1,
		kb_data  => PS2_data1
	);



end architecture;




